sequencetools.iterate_sequence_nwise_strict
===========================================

.. autofunction:: abjad.tools.sequencetools.iterate_sequence_nwise_strict.iterate_sequence_nwise_strict
   :noindex:
